import type { AstPath, Doc, Printer } from "prettier";
import { builders } from "prettier/doc";
import { AliasStatementNode, ArrayExpressionNode, ArrayLiteralNode, AugmentDecoratorStatementNode, CallExpressionNode, Comment, ConstStatementNode, DecoratorDeclarationStatementNode, DecoratorExpressionNode, DirectiveExpressionNode, EnumMemberNode, EnumStatementNode, FunctionDeclarationStatementNode, InterfaceStatementNode, IntersectionExpressionNode, MemberExpressionNode, ModelExpressionNode, ModelPropertyNode, ModelStatementNode, Node, ObjectLiteralNode, ObjectLiteralPropertyNode, ObjectLiteralSpreadPropertyNode, OperationSignatureDeclarationNode, OperationSignatureReferenceNode, OperationStatementNode, StringTemplateExpressionNode, TemplateArgumentNode, TupleExpressionNode, TypeOfExpressionNode, TypeReferenceNode, TypeSpecScriptNode, UnionExpressionNode, UnionStatementNode, UnionVariantNode, ValueOfExpressionNode } from "../../core/types.js";
import { FlattenedNamespaceStatementNode } from "../types.js";
import { DecorableNode, PrettierChildPrint, TypeSpecPrettierOptions } from "./types.js";
export declare const typespecPrinter: Printer<Node>;
export declare function printTypeSpec(path: AstPath<Node>, options: TypeSpecPrettierOptions, print: PrettierChildPrint): Doc;
export declare function printNode(path: AstPath<Node>, options: TypeSpecPrettierOptions, print: PrettierChildPrint): Doc;
export declare function printTypeSpecScript(path: AstPath<TypeSpecScriptNode>, options: TypeSpecPrettierOptions, print: PrettierChildPrint): Doc;
export declare function printAliasStatement(path: AstPath<AliasStatementNode>, options: TypeSpecPrettierOptions, print: PrettierChildPrint): builders.Doc[];
export declare function printConstStatement(path: AstPath<ConstStatementNode>, options: TypeSpecPrettierOptions, print: PrettierChildPrint): builders.Doc[];
export declare function printCallExpression(path: AstPath<CallExpressionNode>, options: TypeSpecPrettierOptions, print: PrettierChildPrint): builders.Doc[];
export declare function canAttachComment(node: Node): boolean;
export declare function printComment(commentPath: AstPath<Node | Comment>, options: TypeSpecPrettierOptions): Doc;
export declare function printDecorators(path: AstPath<DecorableNode>, options: object, print: PrettierChildPrint, { tryInline }: {
    tryInline: boolean;
}): {
    decorators: Doc;
    multiline: boolean;
};
export declare function printDecorator(path: AstPath<DecoratorExpressionNode>, options: TypeSpecPrettierOptions, print: PrettierChildPrint): builders.Doc[];
export declare function printAugmentDecorator(path: AstPath<AugmentDecoratorStatementNode>, options: TypeSpecPrettierOptions, print: PrettierChildPrint): builders.Doc[];
export declare function printDocComments(path: AstPath<Node>, options: object, print: PrettierChildPrint): "" | builders.Group;
export declare function printDirectives(path: AstPath<Node>, options: object, print: PrettierChildPrint): "" | builders.Group;
export declare function printDirective(path: AstPath<DirectiveExpressionNode>, options: TypeSpecPrettierOptions, print: PrettierChildPrint): builders.Doc[];
export declare function printDirectiveArgs(path: AstPath<DirectiveExpressionNode>, options: object, print: PrettierChildPrint): "" | builders.Doc[];
export declare function printEnumStatement(path: AstPath<EnumStatementNode>, options: TypeSpecPrettierOptions, print: PrettierChildPrint): builders.Doc[];
export declare function printEnumMember(path: AstPath<EnumMemberNode>, options: TypeSpecPrettierOptions, print: PrettierChildPrint): builders.Doc[];
export declare function printUnionStatement(path: AstPath<UnionStatementNode>, options: TypeSpecPrettierOptions, print: PrettierChildPrint): builders.Doc[];
export declare function printUnionVariantsBlock(path: AstPath<UnionStatementNode>, options: TypeSpecPrettierOptions, print: PrettierChildPrint): "{}" | builders.Group;
export declare function printUnionVariant(path: AstPath<UnionVariantNode>, options: TypeSpecPrettierOptions, print: PrettierChildPrint): builders.Doc[];
export declare function printInterfaceStatement(path: AstPath<InterfaceStatementNode>, options: TypeSpecPrettierOptions, print: PrettierChildPrint): builders.Doc[];
export declare function printInterfaceMembers(path: AstPath<InterfaceStatementNode>, options: TypeSpecPrettierOptions, print: PrettierChildPrint): "{}" | builders.Group;
/**
 * Handle printing an intersection node.
 * @example `Foo & Bar` or `{foo: string} & {bar: string}`
 *
 * @param path Prettier AST Path.
 * @param options Prettier options
 * @param print Prettier child print callback.
 * @returns Prettier document.
 */
export declare function printIntersection(path: AstPath<IntersectionExpressionNode>, options: object, print: PrettierChildPrint): builders.Group;
export declare function printArray(path: AstPath<ArrayExpressionNode>, options: object, print: PrettierChildPrint): Doc;
export declare function printTuple(path: AstPath<TupleExpressionNode>, options: object, print: PrettierChildPrint): Doc;
export declare function printMemberExpression(path: AstPath<MemberExpressionNode>, options: object, print: PrettierChildPrint): Doc;
export declare function printModelExpression(path: AstPath<ModelExpressionNode>, options: TypeSpecPrettierOptions, print: PrettierChildPrint): builders.Group;
export declare function printObjectLiteral(path: AstPath<ObjectLiteralNode>, options: TypeSpecPrettierOptions, print: PrettierChildPrint): builders.Group | "#{}";
export declare function printObjectLiteralProperty(path: AstPath<ObjectLiteralPropertyNode>, options: TypeSpecPrettierOptions, print: PrettierChildPrint): builders.Doc[];
export declare function printObjectLiteralSpreadProperty(path: AstPath<ObjectLiteralSpreadPropertyNode>, options: TypeSpecPrettierOptions, print: PrettierChildPrint): builders.Doc[];
export declare function printArrayLiteral(path: AstPath<ArrayLiteralNode>, options: TypeSpecPrettierOptions, print: PrettierChildPrint): builders.Group;
export declare function printModelStatement(path: AstPath<ModelStatementNode>, options: TypeSpecPrettierOptions, print: PrettierChildPrint): builders.Doc[];
export declare function printModelProperty(path: AstPath<ModelPropertyNode>, options: TypeSpecPrettierOptions, print: PrettierChildPrint): builders.Doc[];
export declare function printNamespaceStatement(path: AstPath<FlattenedNamespaceStatementNode>, options: TypeSpecPrettierOptions, print: PrettierChildPrint): builders.Doc[];
export declare function printOperationSignatureDeclaration(path: AstPath<OperationSignatureDeclarationNode>, options: TypeSpecPrettierOptions, print: PrettierChildPrint): builders.Doc[];
export declare function printOperationSignatureReference(path: AstPath<OperationSignatureReferenceNode>, options: TypeSpecPrettierOptions, print: PrettierChildPrint): builders.Doc[];
export declare function printOperationStatement(path: AstPath<OperationStatementNode>, options: TypeSpecPrettierOptions, print: PrettierChildPrint): builders.Doc[];
export declare function printStatementSequence<T extends Node>(path: AstPath<T>, options: TypeSpecPrettierOptions, print: PrettierChildPrint, property: keyof T): builders.Doc[];
export declare function printUnion(path: AstPath<UnionExpressionNode>, options: TypeSpecPrettierOptions, print: PrettierChildPrint): builders.Group | builders.Doc[];
export declare function printTypeReference(path: AstPath<TypeReferenceNode>, options: TypeSpecPrettierOptions, print: PrettierChildPrint): Doc;
export declare function printTemplateArgument(path: AstPath<TemplateArgumentNode>, _options: TypeSpecPrettierOptions, print: PrettierChildPrint): Doc;
export declare function printValueOfExpression(path: AstPath<ValueOfExpressionNode>, options: TypeSpecPrettierOptions, print: PrettierChildPrint): Doc;
export declare function printTypeOfExpression(path: AstPath<TypeOfExpressionNode>, options: TypeSpecPrettierOptions, print: PrettierChildPrint): Doc;
export declare function printModifiers(path: AstPath<DecoratorDeclarationStatementNode | FunctionDeclarationStatementNode>, options: TypeSpecPrettierOptions, print: PrettierChildPrint): Doc;
export declare function printStringTemplateExpression(path: AstPath<StringTemplateExpressionNode>, options: TypeSpecPrettierOptions, print: PrettierChildPrint): (string | builders.Indent)[] | (string | builders.Doc[][])[];
//# sourceMappingURL=printer.d.ts.map